database_knotinfo: Content of the KnotInfo and LinkInfo databases as lists of dictionaries
==========================================================================================

Description
-----------

Content of the KnotInfo and LinkInfo databases as lists of dictionaries

License
-------

GPL

Upstream Contact
----------------

https://pypi.org/project/database-knotinfo/

